@@ -21,7 +21,6 @@
  **********************************************************************/
 
 
-
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
@@ -29,10 +28,11 @@
 #include <QProcess>
 #include <QTimer>
 #include <QSettings>
-#include <QFile>
 
 #include <cmd.h>
 
+class QFile;
+
 const QString cli_utils = ". /usr/local/lib/cli-shell-utils/cli-shell-utils.bash;";
 
 namespace Ui {
@@ -47,8 +47,7 @@ public:
     MainWindow(const QStringList &args);
     ~MainWindow();
 
-    bool checkISO();
-    bool checkSize();
+    bool checkDestSize();
     bool isRunningLive();
     bool isToRam();
     void makeUsb(const QString &options);
@@ -57,11 +56,13 @@ public:
     QString buildOptionList();
     QStringList buildUsbList();
     QStringList removeUnsuitable(const QStringList &devices); // remove unsuitable disks from the list (live and unremovable)
+    QString LUM;
 
 
 public slots:
 
 private slots:
+    bool isantiX_mx_family(QString arg1);
     void cleanup();
     void cmdStart();
     void cmdDone();
@@ -69,34 +70,35 @@ private slots:
     void setDefaultMode(const QString &iso_name);
     void updateBar();
     void updateOutput();
-    void on_buttonNext_clicked();
+
     void on_buttonAbout_clicked();
-    void on_buttonHelp_clicked();
     void on_buttonBack_clicked();
-    void on_buttonSelectSource_clicked();
-    void on_buttonRefresh_clicked();
+    void on_buttonHelp_clicked();
+    void on_buttonNext_clicked();
     void on_buttonOptions_clicked();
-    void on_edit_label_textChanged(QString arg1);
-//    void on_buttonEnter_clicked();
-//    void on_lineEdit_returnPressed();
-    void on_cb_update_clicked(bool checked);
-    void on_cb_clone_mode_clicked(bool checked);
+    void on_buttonRefresh_clicked();
+    void on_buttonSelectSource_clicked();
     void on_cb_clone_live_clicked(bool checked);
+    void on_cb_clone_mode_clicked(bool checked);
+    void on_cb_data_first_clicked(bool checked);
+    void on_cb_update_clicked(bool checked);
+    void on_edit_label_textChanged(QString arg1);
+    void on_pushButtonLumLogFile_clicked();
     void on_rb_dd_clicked();
     void on_rb_normal_clicked();
-    bool isantiX_mx_family(QString arg1);
+    void on_spinBoxSize_valueChanged(int arg1);
+//    void on_buttonEnter_clicked();
+//    void on_lineEdit_returnPressed();
 
 private:
     Ui::MainWindow *ui;
     Cmd cmd;
-    Cmd cmd2;
+    QFile *stat_file;
     QString device;
     QTimer timer;
-
     bool advancedOptions;
     int height;
-    int iso_sectors;
-    int start_io;
+    uint size_check;
 };
 
 
